@@ -222,17 +222,13 @@ void
 e_ews_collect_attendees (icalcomponent *comp,
                          GSList **required,
                          GSList **optional,
-                         GSList **resource,
-			 gboolean *out_rsvp_requested)
+                         GSList **resource)
 {
 	icalproperty *prop;
 	icalparameter *param;
 	const gchar *str = NULL;
 	const gchar *org_email_address = NULL;
 
-	if (out_rsvp_requested)
-		*out_rsvp_requested = TRUE;
-
 	/* we need to know who the orgenizer is so we wont duplicate him/her */
 	org_email_address = e_ews_collect_organizer (comp);
 
@@ -266,26 +262,10 @@ e_ews_collect_attendees (icalcomponent *comp,
 		switch (icalparameter_get_role (param)) {
 		case ICAL_ROLE_OPTPARTICIPANT:
 			*optional = g_slist_append (*optional, (gpointer)str);
-
-			if (out_rsvp_requested && *out_rsvp_requested) {
-				icalparameter *rsvp;
-
-				rsvp = icalproperty_get_first_parameter (prop, ICAL_RSVP_PARAMETER);
-				if (rsvp && icalparameter_get_rsvp (rsvp) == ICAL_RSVP_FALSE)
-					*out_rsvp_requested = FALSE;
-			}
 			break;
 		case ICAL_ROLE_CHAIR:
 		case ICAL_ROLE_REQPARTICIPANT:
 			*required = g_slist_append (*required, (gpointer)str);
-
-			if (out_rsvp_requested && *out_rsvp_requested) {
-				icalparameter *rsvp;
-
-				rsvp = icalproperty_get_first_parameter (prop, ICAL_RSVP_PARAMETER);
-				if (rsvp && icalparameter_get_rsvp (rsvp) == ICAL_RSVP_FALSE)
-					*out_rsvp_requested = FALSE;
-			}
 			break;
 		case ICAL_ROLE_NONPARTICIPANT:
 			*resource = g_slist_append (*resource, (gpointer)str);
@@ -328,7 +308,8 @@ ews_get_alarm (ECalComponent *comp)
 
 void
 ews_set_alarm (ESoapMessage *msg,
-               ECalComponent *comp)
+               ECalComponent *comp,
+	       gboolean with_due_by)
 {
 	/* We know there would be only a single alarm in EWS calendar item */
 	GList *alarm_uids = e_cal_component_get_alarm_uids (comp);
@@ -339,14 +320,23 @@ ews_set_alarm (ESoapMessage *msg,
 	e_cal_component_alarm_get_action (alarm, &action);
 	if (action == E_CAL_COMPONENT_ALARM_DISPLAY) {
 		ECalComponentAlarmTrigger trigger;
-		gchar buf[20];
 		gint dur_int = 0;
+
 		e_cal_component_alarm_get_trigger (alarm, &trigger);
 		switch (trigger.type) {
 		case E_CAL_COMPONENT_ALARM_TRIGGER_RELATIVE_START:
 			dur_int = ((icaldurationtype_as_int (trigger.u.rel_duration)) / SECS_IN_MINUTE) * -1;
-			snprintf (buf, 20, "%d", dur_int);
-			e_ews_message_write_string_parameter (msg, "ReminderMinutesBeforeStart", NULL, buf);
+			e_ews_message_write_int_parameter (msg, "ReminderMinutesBeforeStart", NULL, dur_int);
+			if (with_due_by) {
+				struct icaltimetype dtstart;
+
+				dtstart = icalcomponent_get_dtstart (e_cal_component_get_icalcomponent (comp));
+
+				if (!icaltime_is_null_time (dtstart)) {
+					e_ews_message_write_time_parameter (msg, "ReminderDueBy", NULL,
+						icaltime_as_timet_with_zone (dtstart, icaltimezone_get_utc_timezone ()));
+				}
+			}
 			break;
 		default:
 			break;
@@ -1069,9 +1059,10 @@ check_is_all_day_event (const struct icaltimetype dtstart,
 	return ((secs_end - secs_start) % (24 * 60 * 60)) == 0 && (secs_start % 24 * 60 * 60) == 0;
 }
 
-static void
+static gboolean
 convert_vevent_calcomp_to_xml (ESoapMessage *msg,
-                               gpointer user_data)
+                               gpointer user_data,
+			       GError **error)
 {
 	EwsCalendarConvertData *convert_data = user_data;
 	icalcomponent *icalcomp = convert_data->icalcomp;
@@ -1080,7 +1071,7 @@ convert_vevent_calcomp_to_xml (ESoapMessage *msg,
 	icaltimetype dtstart, dtend;
 	icaltimezone *tzid_start, *tzid_end;
 	icalproperty *prop;
-	gboolean has_alarms, satisfies, rsvp_requested = TRUE;
+	gboolean has_alarms, satisfies;
 	const gchar *ical_location_start, *ical_location_end, *value;
 	const gchar *msdn_location_start, *msdn_location_end;
 
@@ -1108,16 +1099,16 @@ convert_vevent_calcomp_to_xml (ESoapMessage *msg,
 	/* set alarms */
 	has_alarms = e_cal_component_has_alarms (comp);
 	if (has_alarms)
-		ews_set_alarm (msg, comp);
+		ews_set_alarm (msg, comp, FALSE);
 	else
 		e_ews_message_write_string_parameter (msg, "ReminderIsSet", NULL, "false");
 
 	/* start time, end time and meeting time zone */
-	dtstart = e_cal_backend_ews_get_datetime_with_zone (convert_data->timezone_cache, icalcomp, ICAL_DTSTART_PROPERTY, icalproperty_get_dtstart);
+	dtstart = icalcomponent_get_dtstart (icalcomp);
 	tzid_start = (icaltimezone *) (dtstart.zone ? dtstart.zone : convert_data->default_zone);
 	ical_location_start = icaltimezone_get_location (tzid_start);
 
-	dtend = e_cal_backend_ews_get_datetime_with_zone (convert_data->timezone_cache, icalcomp, ICAL_DTEND_PROPERTY, icalproperty_get_dtend);
+	dtend = icalcomponent_get_dtend (icalcomp);
 	tzid_end = (icaltimezone *) (dtend.zone ? dtend.zone : convert_data->default_zone);
 	ical_location_end = icaltimezone_get_location (tzid_end);
 
@@ -1165,9 +1156,7 @@ convert_vevent_calcomp_to_xml (ESoapMessage *msg,
 		e_ews_message_write_string_parameter (msg, "Location", NULL, value);
 
 	/* collect attendees */
-	e_ews_collect_attendees (icalcomp, &required, &optional, &resource, &rsvp_requested);
-
-	e_ews_message_write_string_parameter (msg, "IsResponseRequested", NULL, rsvp_requested ? "true" : "false");
+	e_ews_collect_attendees (icalcomp, &required, &optional, &resource);
 
 	if (required != NULL) {
 		add_attendees_list_to_message (msg, "RequiredAttendees", required);
@@ -1225,23 +1214,14 @@ convert_vevent_calcomp_to_xml (ESoapMessage *msg,
 	e_soap_message_end_element (msg); /* "CalendarItem" */
 
 	g_object_unref (comp);
+
+	return TRUE;
 }
 
-static const gchar *
-ews_priority_to_string (gint priority)
-{
-	if (priority <= 3)
-		return "High";
-
-	if (priority >= 7)
-		return "Low";
-
-	return "Normal";
-}
-
-static void
+static gboolean
 convert_vtodo_calcomp_to_xml (ESoapMessage *msg,
-                              gpointer user_data)
+                              gpointer user_data,
+			      GError **error)
 {
 	EwsCalendarConvertData *convert_data = user_data;
 	icalcomponent *icalcomp = convert_data->icalcomp;
@@ -1249,6 +1229,8 @@ convert_vtodo_calcomp_to_xml (ESoapMessage *msg,
 	icaltimetype dt;
 	gint value;
 	gchar buffer[16];
+	gboolean success;
+	/* gboolean has_alarms; */
 
 	e_soap_message_start_element (msg, "Task", NULL, NULL);
 
@@ -1260,17 +1242,9 @@ convert_vtodo_calcomp_to_xml (ESoapMessage *msg,
 
 	convert_categories_calcomp_to_xml (msg, NULL, icalcomp);
 
-	prop = icalcomponent_get_first_property (icalcomp, ICAL_PRIORITY_PROPERTY);
-	if (prop) {
-		gint priority;
-
-		priority = icalproperty_get_priority (prop);
-		e_ews_message_write_string_parameter (msg, "Importance", NULL, ews_priority_to_string (priority));
-	}
-
 	prop = icalcomponent_get_first_property (icalcomp, ICAL_DUE_PROPERTY);
 	if (prop) {
-		dt = e_cal_backend_ews_get_datetime_with_zone (convert_data->timezone_cache, icalcomp, ICAL_DUE_PROPERTY, icalproperty_get_due);
+		dt = icalproperty_get_due (prop);
 		e_ews_cal_utils_set_time (msg, "DueDate", &dt, TRUE);
 	}
 
@@ -1281,9 +1255,11 @@ convert_vtodo_calcomp_to_xml (ESoapMessage *msg,
 		e_ews_message_write_string_parameter (msg, "PercentComplete", NULL, buffer);
 	}
 
+	success = e_ews_cal_utils_set_recurrence (msg, icalcomp, FALSE, error);
+
 	prop = icalcomponent_get_first_property (icalcomp, ICAL_DTSTART_PROPERTY);
 	if (prop) {
-		dt = e_cal_backend_ews_get_datetime_with_zone (convert_data->timezone_cache, icalcomp, ICAL_DTSTART_PROPERTY, icalproperty_get_dtstart);
+		dt = icalproperty_get_dtstart (prop);
 		e_ews_cal_utils_set_time (msg, "StartDate", &dt, TRUE);
 	}
 
@@ -1301,12 +1277,31 @@ convert_vtodo_calcomp_to_xml (ESoapMessage *msg,
 		}
 	}
 
+	/* has_alarms = icalcomponent_get_first_component (icalcomp, ICAL_VALARM_COMPONENT) != NULL;
+	if (has_alarms) {
+		ECalComponent *comp = e_cal_component_new_from_icalcomponent (icalcomponent_new_clone (icalcomp));
+
+		if (comp && e_cal_component_has_alarms (comp)) {
+			ews_set_alarm (msg, comp, TRUE);
+		} else {
+			has_alarms = FALSE;
+		}
+
+		g_clear_object (&comp);
+	}
+
+	if (!has_alarms)
+		e_ews_message_write_string_parameter (msg, "ReminderIsSet", NULL, "false");*/
+
 	e_soap_message_end_element (msg); /* "Task" */
+
+	return success;
 }
 
-static void
+static gboolean
 convert_vjournal_calcomp_to_xml (ESoapMessage *msg,
-				 gpointer user_data)
+				 gpointer user_data,
+				 GError **error)
 {
 	EwsCalendarConvertData *convert_data = user_data;
 	icalcomponent *icalcomp = convert_data->icalcomp;
@@ -1327,28 +1322,34 @@ convert_vjournal_calcomp_to_xml (ESoapMessage *msg,
 	convert_categories_calcomp_to_xml (msg, NULL, icalcomp);
 
 	e_soap_message_end_element (msg); /* Message */
+
+	return TRUE;
 }
 
-void
+gboolean
 e_cal_backend_ews_convert_calcomp_to_xml (ESoapMessage *msg,
-					  gpointer user_data)
+					  gpointer user_data,
+					  GError **error)
 {
 	EwsCalendarConvertData *convert_data = user_data;
+	gboolean success = FALSE;
 
 	switch (icalcomponent_isa (convert_data->icalcomp)) {
 	case ICAL_VEVENT_COMPONENT:
-		convert_vevent_calcomp_to_xml (msg, convert_data);
+		success = convert_vevent_calcomp_to_xml (msg, convert_data, error);
 		break;
 	case ICAL_VTODO_COMPONENT:
-		convert_vtodo_calcomp_to_xml (msg, convert_data);
+		success = convert_vtodo_calcomp_to_xml (msg, convert_data, error);
 		break;
 	case ICAL_VJOURNAL_COMPONENT:
-		convert_vjournal_calcomp_to_xml (msg, convert_data);
+		success = convert_vjournal_calcomp_to_xml (msg, convert_data, error);
 		break;
 	default:
 		g_warn_if_reached ();
 		break;
 	}
+
+	return success;
 }
 
 static void
@@ -1408,9 +1409,10 @@ convert_vevent_property_to_updatexml (ESoapMessage *msg,
 	e_ews_message_end_set_item_field (msg);
 }
 
-static void
+static gboolean
 convert_vevent_component_to_updatexml (ESoapMessage *msg,
-                                       gpointer user_data)
+                                       gpointer user_data,
+				       GError **error)
 {
 	EwsCalendarConvertData *convert_data = user_data;
 	icalcomponent *icalcomp = e_cal_component_get_icalcomponent (convert_data->comp);
@@ -1427,10 +1429,9 @@ convert_vevent_component_to_updatexml (ESoapMessage *msg,
 	gboolean has_alarms, has_alarms_old;
 	gboolean dt_start_changed = FALSE, dt_end_changed = FALSE, dt_changed;
 	gboolean dt_start_changed_timezone_name = FALSE, dt_end_changed_timezone_name = FALSE;
-	gboolean satisfies, rsvp_requested = TRUE;
+	gboolean satisfies;
 	gint alarm = 0, alarm_old = 0;
 	gchar *recid;
-	GError *error = NULL;
 
 	/* Modifying a recurring meeting ? */
 	if (icalcomponent_get_first_property (icalcomp_old, ICAL_RRULE_PROPERTY) != NULL) {
@@ -1447,7 +1448,7 @@ convert_vevent_component_to_updatexml (ESoapMessage *msg,
 					convert_data->default_zone,
 					recid,
 					icalcomp_old,
-					&error));
+					NULL));
 			g_free (recid);
 		} else {
 			e_ews_message_start_item_change (
@@ -1530,12 +1531,13 @@ convert_vevent_component_to_updatexml (ESoapMessage *msg,
 	org_email_address = e_ews_collect_organizer (icalcomp);
 	if (org_email_address && convert_data->user_email && g_ascii_strcasecmp (org_email_address, convert_data->user_email)) {
 		e_ews_message_end_item_change (msg);
-		return;
+		return TRUE;
 	}
+
 	/* Update other properties allowed only for meeting organizers*/
 	/*meeting dates*/
-	dtstart = e_cal_backend_ews_get_datetime_with_zone (convert_data->timezone_cache, icalcomp, ICAL_DTSTART_PROPERTY, icalproperty_get_dtstart);
-	dtstart_old = e_cal_backend_ews_get_datetime_with_zone (convert_data->timezone_cache, icalcomp_old, ICAL_DTSTART_PROPERTY, icalproperty_get_dtstart);
+	dtstart = icalcomponent_get_dtstart (icalcomp);
+	dtstart_old = icalcomponent_get_dtstart (icalcomp_old);
 	dt_start_changed = icaltime_compare (dtstart, dtstart_old) != 0;
 	if (dtstart.zone != NULL) {
 		tzid_start = (icaltimezone *) dtstart.zone;
@@ -1546,8 +1548,8 @@ convert_vevent_component_to_updatexml (ESoapMessage *msg,
 			dt_start_changed_timezone_name = TRUE;
 	}
 
-	dtend = e_cal_backend_ews_get_datetime_with_zone (convert_data->timezone_cache, icalcomp, ICAL_DTEND_PROPERTY, icalproperty_get_dtend);
-	dtend_old = e_cal_backend_ews_get_datetime_with_zone (convert_data->timezone_cache, icalcomp_old, ICAL_DTEND_PROPERTY, icalproperty_get_dtend);
+	dtend = icalcomponent_get_dtend (icalcomp);
+	dtend_old = icalcomponent_get_dtend (icalcomp_old);
 	dt_end_changed = icaltime_compare (dtend, dtend_old) != 0;
 	if (dtend.zone != NULL) {
 		tzid_end = (icaltimezone *) dtend.zone;
@@ -1618,10 +1620,7 @@ convert_vevent_component_to_updatexml (ESoapMessage *msg,
 			convert_vevent_property_to_updatexml (msg, "IsAllDayEvent", "false", "calendar", NULL, NULL);
 	}
 
-	e_ews_collect_attendees (icalcomp, &required, &optional, &resource, &rsvp_requested);
-
-	convert_vevent_property_to_updatexml (msg, "IsResponseRequested", rsvp_requested ? "true" : "false", "calendar", NULL, NULL);
-
+	e_ews_collect_attendees (icalcomp, &required, &optional, &resource);
 	if (required != NULL) {
 		e_ews_message_start_set_item_field (msg, "RequiredAttendees", "calendar", "CalendarItem");
 
@@ -1715,6 +1714,8 @@ convert_vevent_component_to_updatexml (ESoapMessage *msg,
 	}
 
 	e_ews_message_end_item_change (msg);
+
+	return TRUE;
 }
 
 static void
@@ -1730,9 +1731,10 @@ convert_vtodo_property_to_updatexml (ESoapMessage *msg,
 	e_ews_message_end_set_item_field (msg);
 }
 
-static void
+static gboolean
 convert_vtodo_component_to_updatexml (ESoapMessage *msg,
-                                      gpointer user_data)
+                                      gpointer user_data,
+				      GError **error)
 {
 	EwsCalendarConvertData *convert_data = user_data;
 	icalcomponent *icalcomp = e_cal_component_get_icalcomponent (convert_data->comp);
@@ -1740,6 +1742,7 @@ convert_vtodo_component_to_updatexml (ESoapMessage *msg,
 	icaltimetype dt;
 	gint value;
 	gchar buffer[16];
+	gboolean success = TRUE;
 
 	e_ews_message_start_item_change (
 		msg, E_EWS_ITEMCHANGE_TYPE_ITEM,
@@ -1763,7 +1766,7 @@ convert_vtodo_component_to_updatexml (ESoapMessage *msg,
 
 	prop = icalcomponent_get_first_property (icalcomp, ICAL_DUE_PROPERTY);
 	if (prop) {
-		dt = e_cal_backend_ews_get_datetime_with_zone (convert_data->timezone_cache, icalcomp, ICAL_DUE_PROPERTY, icalproperty_get_due);
+		dt = icalproperty_get_due (prop);
 		e_ews_message_start_set_item_field (msg, "DueDate", "task", "Task");
 		e_ews_cal_utils_set_time (msg, "DueDate", &dt, TRUE);
 		e_ews_message_end_set_item_field (msg);
@@ -1780,9 +1783,20 @@ convert_vtodo_component_to_updatexml (ESoapMessage *msg,
 		e_ews_message_end_set_item_field (msg);
 	}
 
+	/* Recurrence */
+	value = icalcomponent_count_properties (e_cal_component_get_icalcomponent (convert_data->old_comp), ICAL_RRULE_PROPERTY);
+	if (icalcomponent_count_properties (icalcomp, ICAL_RRULE_PROPERTY) > 0 ||
+	    (e_cal_util_find_x_property (icalcomp, X_EWS_TASK_REGENERATION) && value <= 0)) {
+		e_ews_message_start_set_item_field (msg, "Recurrence", "task", "Task");
+		success = success && e_ews_cal_utils_set_recurrence (msg, icalcomp, FALSE, error);
+		e_ews_message_end_set_item_field (msg); /* Recurrence */
+	} else if (value > 0) {
+		e_ews_message_add_delete_item_field (msg, "Recurrence", "task");
+	}
+
 	prop = icalcomponent_get_first_property (icalcomp, ICAL_DTSTART_PROPERTY);
 	if (prop) {
-		dt = e_cal_backend_ews_get_datetime_with_zone (convert_data->timezone_cache, icalcomp, ICAL_DTSTART_PROPERTY, icalproperty_get_dtstart);
+		dt = icalproperty_get_dtstart (prop);
 		e_ews_message_start_set_item_field (msg, "StartDate", "task", "Task");
 		e_ews_cal_utils_set_time (msg, "StartDate", &dt, TRUE);
 		e_ews_message_end_set_item_field (msg);
@@ -1811,15 +1825,9 @@ convert_vtodo_component_to_updatexml (ESoapMessage *msg,
 	/* Categories */
 	convert_component_categories_to_updatexml (convert_data->comp, msg, "Task");
 
-	prop = icalcomponent_get_first_property (icalcomp, ICAL_PRIORITY_PROPERTY);
-	if (prop) {
-		gint priority;
-
-		priority = icalproperty_get_priority (prop);
-		convert_vtodo_property_to_updatexml (msg, "Importance", ews_priority_to_string (priority), "item", NULL, NULL);
-	}
-
 	e_ews_message_end_item_change (msg);
+
+	return success;
 }
 
 static void
@@ -1835,9 +1843,10 @@ convert_vjournal_property_to_updatexml (ESoapMessage *msg,
 	e_ews_message_end_set_item_field (msg);
 }
 
-static void
+static gboolean
 convert_vjournal_component_to_updatexml (ESoapMessage *msg,
-					 gpointer user_data)
+					 gpointer user_data,
+					 GError **error)
 {
 	EwsCalendarConvertData *convert_data = user_data;
 	icalcomponent *icalcomp = e_cal_component_get_icalcomponent (convert_data->comp);
@@ -1873,28 +1882,34 @@ convert_vjournal_component_to_updatexml (ESoapMessage *msg,
 	convert_component_categories_to_updatexml (convert_data->comp, msg, "Message");
 
 	e_ews_message_end_item_change (msg);
+
+	return TRUE;
 }
 
-void
+gboolean
 e_cal_backend_ews_convert_component_to_updatexml (ESoapMessage *msg,
-						  gpointer user_data)
+						  gpointer user_data,
+						  GError **error)
 {
 	EwsCalendarConvertData *convert_data = user_data;
 	icalcomponent *icalcomp = e_cal_component_get_icalcomponent (convert_data->comp);
+	gboolean success = FALSE;
 
 	switch (icalcomponent_isa (icalcomp)) {
 	case ICAL_VEVENT_COMPONENT:
-		convert_vevent_component_to_updatexml (msg, user_data);
+		success = convert_vevent_component_to_updatexml (msg, user_data, error);
 		break;
 	case ICAL_VTODO_COMPONENT:
-		convert_vtodo_component_to_updatexml (msg, user_data);
+		success = convert_vtodo_component_to_updatexml (msg, user_data, error);
 		break;
 	case ICAL_VJOURNAL_COMPONENT:
-		convert_vjournal_component_to_updatexml (msg, user_data);
+		success = convert_vjournal_component_to_updatexml (msg, user_data, error);
 		break;
 	default:
 		break;
 	}
+
+	return success;
 }
 
 guint
@@ -1936,9 +1951,10 @@ e_cal_backend_ews_rid_to_index (icaltimezone *timezone,
 	return index;
 }
 
-void
+gboolean
 e_cal_backend_ews_clear_reminder_is_set (ESoapMessage *msg,
-					 gpointer user_data)
+					 gpointer user_data,
+					 GError **error)
 {
 	EwsCalendarConvertData *convert_data = user_data;
 
@@ -1956,11 +1972,14 @@ e_cal_backend_ews_clear_reminder_is_set (ESoapMessage *msg,
 	e_ews_message_end_set_item_field (msg);
 
 	e_ews_message_end_item_change (msg);
+
+	return TRUE;
 }
 
-void
+gboolean
 e_cal_backend_ews_prepare_set_free_busy_status (ESoapMessage *msg,
-						gpointer user_data)
+						gpointer user_data,
+						GError **error)
 {
 	EwsCalendarConvertData *data = user_data;
 
@@ -1973,11 +1992,14 @@ e_cal_backend_ews_prepare_set_free_busy_status (ESoapMessage *msg,
 	e_ews_message_end_set_item_field (msg);
 
 	e_ews_message_end_item_change (msg);
+
+	return TRUE;
 }
 
-void
+gboolean
 e_cal_backend_ews_prepare_accept_item_request (ESoapMessage *msg,
-					       gpointer user_data)
+					       gpointer user_data,
+					       GError **error)
 {
 	EwsCalendarConvertData *data = user_data;
 	const gchar *response_type = data->response_type;
@@ -2002,42 +2024,6 @@ e_cal_backend_ews_prepare_accept_item_request (ESoapMessage *msg,
 
 	/* end of "AcceptItem" */
 	e_soap_message_end_element (msg);
-}
 
-struct icaltimetype
-e_cal_backend_ews_get_datetime_with_zone (ETimezoneCache *timezone_cache,
-					  icalcomponent *comp,
-					  icalproperty_kind prop_kind,
-					  struct icaltimetype (* get_func) (const icalproperty *prop))
-{
-	struct icaltimetype dt = icaltime_null_time ();
-	icalproperty *prop;
-	icalparameter *param;
-	const gchar *tzid;
-
-	g_return_val_if_fail (E_IS_TIMEZONE_CACHE (timezone_cache), dt);
-	g_return_val_if_fail (comp != NULL, dt);
-	g_return_val_if_fail (get_func != NULL, dt);
-
-	prop = icalcomponent_get_first_property (comp, prop_kind);
-	if (!prop)
-		return dt;
-
-	dt = get_func (prop);
-
-	if (!icaltime_is_valid_time (dt) ||
-	    icaltime_is_null_time (dt))
-		return dt;
-
-	param = icalproperty_get_first_parameter (prop, ICAL_TZID_PARAMETER);
-	if (!param)
-		return dt;
-
-	tzid = icalparameter_get_tzid (param);
-	if (!tzid || !*tzid)
-		return dt;
-
-	dt.zone = e_timezone_cache_get_timezone (timezone_cache, tzid);
-
-	return dt;
+	return TRUE;
 }
